@@ -26,16 +26,16 @@ def get_promoter(args):
         for g in db.all_features(featuretype='gene', order_by="seqid"):
             if g.strand == "+":
                 gene_seq = g.sequence(args.genome, use_strand=True)
-                p_start = g.start - int(args.promoter_length)
+                p_start = g.start - int(args.promoter_length) - 1 # transform 1-based to 0-based
                 if p_start < 0 :
                     continue
-                p_end = g.start + args.utr5_upper_length
+                p_end = g.start + args.utr5_upper_length - 1 # include first base of TSS, transform 1-based to 0-based
                 promoter = genomeDict[g.chrom][p_start:p_end]
                 # print(promoter)
             elif g.strand == "-":
                 gene_seq = g.sequence(args.genome, use_strand=True)
-                p_start = g.end - args.utr5_upper_length
-                p_end = g.end + int(args.promoter_length)
+                p_start = g.end - args.utr5_upper_length - 1
+                p_end = g.end + int(args.promoter_length) - 1
                 promoter = genomeDict[g.chrom][p_start:p_end].reverse_complement()
                 # print(promoter)
             p_start_in_genome = p_start
