@@ -15,7 +15,9 @@ from featurExtract.extract_promoter import get_promoter
 from featurExtract.extract_exon import get_exon
 from featurExtract.extract_intron import get_intron
 from featurExtract.extract_gene import get_gene
-from featurExtract.extract_intergenic import get_intergenic
+from featurExtract.extract_IGR import get_IGR
+from featurExtract.extract_cdna import get_cdna
+from featurExtract.extract_mRNA import get_mRNA
 
 
 def create(args):
@@ -104,12 +106,26 @@ def gene(args):
     '''
     get_gene(args)
 
-def intergenic(args):
+def mRNA(args):
     '''
     parameters:
      args: arguments from argparse
     '''
-    get_intergenic(args)
+    get_mRNA(args)
+
+def cdna(args):
+    '''
+    parameters:
+     args: arguments from argparse
+    '''
+    get_cdna(args)
+
+def IGR(args):
+    '''
+    parameters:
+     args: arguments from argparse
+    '''
+    get_IGR(args)
 
 parser = argparse.ArgumentParser()
 subparsers = parser.add_subparsers(help='sub-command help')
@@ -129,7 +145,7 @@ parser_promoter.add_argument('-u', '--utr5_upper_length', type=int, help='utr5 l
 parser_promoter.add_argument('-f', '--genome', type=str, help='genome fasta')
 parser_promoter.add_argument('-o', '--output', type=str, help = 'output csv file path')
 parser_promoter.add_argument('-p', '--print', action="store_true", help='boolean type, stdin')
-parser_promoter.add_argument('-s', '--style', choices=['GFF','GTF'], help = 'GTF database or GFF database')
+#parser_promoter.add_argument('-s', '--style', choices=['GFF','GTF'], help = 'GTF database or GFF database')
 parser_promoter.set_defaults(func=promoter)
 
 # gene subcommand 
@@ -139,18 +155,43 @@ parser_gene.add_argument('-g', '--gene', type=str, help='specific gene; if not g
 parser_gene.add_argument('-f', '--genome', type=str, help='genome fasta')
 parser_gene.add_argument('-o', '--output', type=str, help = 'output csv file path')
 parser_gene.add_argument('-p', '--print', action="store_true", help='boolean type, stdin')
-parser_gene.add_argument('-s', '--style', choices=['GFF','GTF'], help = 'GTF database or GFF database')
+#parser_gene.add_argument('-s', '--style', choices=['GFF','GTF'], help = 'GTF database or GFF database')
 parser_gene.set_defaults(func=gene)
 
-# intergenic subcommand 
-parser_intergenic = subparsers.add_parser('intergenic', help='extract intergenic in genome or gene')
-parser_intergenic.add_argument('-d', '--database', type=str, help='database generated by subcommand create')
-parser_intergenic.add_argument('-f', '--genome', type=str, help='genome fasta')
-parser_intergenic.add_argument('-l', '--intergene_length', type=int, help='intergenic length')
-parser_intergenic.add_argument('-o', '--output', type=str, help = 'output csv file path')
-parser_intergenic.add_argument('-p', '--print', action="store_true", help='boolean type, stdin')
-parser_intergenic.add_argument('-s', '--style', choices=['GFF','GTF'], help = 'GTF database or GFF database')
-parser_intergenic.set_defaults(func=intergenic)
+# mRNA subcommand 
+parser_mRNA = subparsers.add_parser('mRNA', help='extract mature messager RNA in genome or gene')
+parser_mRNA.add_argument('-d', '--database', type=str, help='database generated by subcommand create')
+parser_mRNA.add_argument('-t', '--transcript', type=str, help='specific transcript; if not given, return whole transcripts')
+parser_mRNA.add_argument('-f', '--genome', type=str, help='genome fasta')
+parser_mRNA.add_argument('-o', '--output', type=str, help = 'output csv file path')
+parser_mRNA.add_argument('-p', '--print', action="store_true", help='boolean type, stdin')
+parser_mRNA.add_argument('-u', '--upper', action="store_true", help='boolean type, stdin')
+parser_mRNA.add_argument('-s', '--style', choices=['GFF','GTF'], help = 'GTF database or GFF database')
+parser_mRNA.set_defaults(func=mRNA)
+
+
+# cdna subcommand 
+parser_cdna = subparsers.add_parser('cdna', help='extract cdna (or refMrna) in genome or gene')
+parser_cdna.add_argument('-d', '--database', type=str, help='database generated by subcommand create')
+parser_cdna.add_argument('-t', '--transcript', type=str, help='specific transcript; if not given, return whole transcripts')
+parser_cdna.add_argument('-f', '--genome', type=str, help='genome fasta')
+parser_cdna.add_argument('-o', '--output', type=str, help = 'output csv file path')
+parser_cdna.add_argument('-p', '--print', action="store_true", help='boolean type, stdin')
+parser_cdna.add_argument('-u', '--upper', action="store_true", help='boolean type, stdin')
+parser_cdna.add_argument('-s', '--style', choices=['GFF','GTF'], help = 'GTF database or GFF database')
+parser_cdna.set_defaults(func=cdna)
+
+
+# IGR subcommand 
+parser_IGR = subparsers.add_parser('IGR', help='extract IGR in genome or gene')
+parser_IGR.add_argument('-d', '--database', type=str, help='database generated by subcommand create')
+parser_IGR.add_argument('-f', '--genome', type=str, help='genome fasta')
+parser_IGR.add_argument('-l', '--IGR_length', type=int, help='IGR length threshold')
+parser_IGR.add_argument('-o', '--output', type=str, help = 'output fasta file path')
+parser_IGR.add_argument('-p', '--print', action="store_true", help='boolean type, stdin')
+parser_IGR.add_argument('-s', '--style', choices=['GFF','GTF'], help = 'GTF database only contain \
+                       protein genes, while GFF database contain protein genes and nocoding genes')
+parser_IGR.set_defaults(func=IGR)
 
 # UTR subcommand
 parser_utr = subparsers.add_parser('UTR', help='extract untranslated region sequence in genome or gene')
@@ -168,7 +209,7 @@ parser_uORF = subparsers.add_parser('uORF', help='extract upper stream open read
 parser_uORF.add_argument('-d', '--database', type=str, help='database generated by subcommand create')
 parser_uORF.add_argument('-f', '--genome', type=str, help='genome fasta')
 parser_uORF.add_argument('-t', '--transcript', type=str, help='specific transcript id; if not given, \
-                       whole transcript will return')
+                               whole transcript will return')
 parser_uORF.add_argument('-o', '--output', type=str, help='output file path')
 parser_uORF.add_argument('-s', '--style', choices=['GFF','GTF'], help = 'GTF database or GFF database')
 parser_uORF.set_defaults(func=uORF)
@@ -190,7 +231,7 @@ parser_dORF = subparsers.add_parser('dORF', help='extract down stream open readi
 parser_dORF.add_argument('-d', '--database', type=str, help='database generated by subcommand create')
 parser_dORF.add_argument('-f', '--genome', type=str, help='genome fasta')
 parser_dORF.add_argument('-t', '--transcript', type=str, help='specific transcript id; if not given, \
-                       whole transcript will return')
+                               whole transcript will return')
 parser_dORF.add_argument('-o', '--output', type=str, help='output file path')
 parser_dORF.add_argument('-p', '--print', action="store_true", help='stdin')
 parser_dORF.add_argument('-s', '--style', choices=['GFF','GTF'], help = 'GTF database or GFF database')
